@@ -73,7 +73,11 @@ if __name__ == '__main__':
     #CurtoPrazo = Dessem("/Users/andremarcato/Dropbox/Projeto ReadDessem/DS_CCEE_082020_SEMREDE_RV0D01","dessem.arq")
     MedioPrazo = Newave("/Users/andremarcato/Dropbox/Projeto ReadDessem/Deck_Newave")
 
-    uhe = MedioPrazo.confhd.get('furnas')
+    print(MedioPrazo.hidr.nr_usinas)
+
+    uhe = MedioPrazo.confhd.get('itaipu')
+
+    print(uhe['jusante'])
 
     MedioPrazo.confhd.plot_pcv(uhe)
     MedioPrazo.confhd.plot_pca(uhe)
